=======
History
=======

0.1.0 (2019-08-15)
------------------

* First release on PyPI.


0.1.1 (2019-10-11)
------------------

* Added interactive plots.

0.1.6 (2020-01-22)
------------------

* Updated TSO plot to highlight active data in subplots.

0.1.9 (2023-08-16)
------------------

* Adds Python 3.9 and 3.10 support and drops lower Python version support

0.1.10 (2024-07-23)
-------------------

* Removes Python 3.9 support and adds Python 3.11 support. Also fixes a deprecation error caused by bokeh.